@@ -1,14 +1,18 @@
+from __future__ import annotations
+
+import typing as t
+
 import pytest
 
 from blinker import Signal
 
 
-def test_temp_connection():
+def test_temp_connection() -> None:
     sig = Signal()
 
     canary = []
 
-    def receiver(sender):
+    def receiver(sender: t.Any) -> None:
         canary.append(sender)
 
     sig.send(1)
@@ -20,12 +24,12 @@ def test_temp_connection():
     assert not sig.receivers
 
 
-def test_temp_connection_for_sender():
+def test_temp_connection_for_sender() -> None:
     sig = Signal()
 
     canary = []
 
-    def receiver(sender):
+    def receiver(sender: t.Any) -> None:
         canary.append(sender)
 
     with sig.connected_to(receiver, sender=2):
@@ -45,18 +49,15 @@ class BaseFailure(BaseException):
 
 
 @pytest.mark.parametrize("exc_type", [Failure, BaseFailure])
-def test_temp_connection_failure(exc_type):
+def test_temp_connection_failure(exc_type: type[BaseException]) -> None:
     sig = Signal()
 
     canary = []
 
-    def receiver(sender):
+    def receiver(sender: t.Any) -> None:
         canary.append(sender)
 
-    class Failure(Exception):
-        pass
-
-    with pytest.raises(exc_type):  # noqa: B908
+    with pytest.raises(exc_type):
         sig.send(1)
         with sig.connected_to(receiver):
             sig.send(2)
